==> phpwebthings-0.6.0.zip: phpwebthings-0.6.0/lang/msg_ptbr.php <==
<?php
// Portuguese - Brasil file for phpwebthings - Paulo Assis <paulo@phpdbform.com>
$lang = array(
"CHARSET"=>"iso-8859-1",
//general
"ACTIVATE_TITLE"=>"Conta ativada!",
"ADD_USERS"=>"Adiciona contatos",
"REPLIES_TO"=>"Responder para",
"PREVIOUS_MSG"=>"Mensagem anterior no tpico",
"BACK_FORUM"=>"Voltar para o frum",
"OPTION_NONE"=>"none",
"GO_BACK"=>"Voltar",
"PAGE_PROCESSED"=>"Pgina processada em %.4f segundos",

// general not logged
"NOT_LOGGED_ONLINE"=>"Desculpe, mas voc precisa se logar no site para ver os usurios online. Se voc no tem um login, porque no se registra?  grtis!",
"NOT_LOGGED_MYACCT"=>"Desculpe, mas voc precisa se logar no site para editar seus dados. Se voc no tem um login, porque no se registra?  grtis!",

//home
"HOME_TITLE"=>"Principal",

//error messages
"ERROR_TITLE"=>"*** ERRO ***",
"ERROR_01"=>"Voc no pode postar uma mensagem sem um ttulo e/ou um texto",
"ERROR_02"=>"Voc precisa informar um ttulo<br>",
"ERROR_03"=>"Voc precisa informar um texto<br>",
"ERROR_04"=>"Ocorreu um erro ao executar um comando SQL",
"ERROR_05"=>"Erro abrindo diretrio",
"ERROR_06"=>"banner no encontrado",
"ERROR_07"=>"arquivo no encontrado",
"ERROR_08"=>"E-mail invlido<br>",
"ERROR_09"=>"E-mail no econtrado!<br>",
"ERROR_10"=>"Erro de anlise: ",
"ERROR_11"=>"Ao negada",

// not logged messages
//NOT_LOGGED_ONLINE
//NOT_LOGGED_MYACCT

// MyAccount / NewUser
"MYACCT_TITLE"=>"Minha conta",
"MYACCT_INFO"=>"Informaes sobre meu login",
"MYACCT_TEXT"=>"Todos os dados informados aqui, menos o e-mail, podero ser visualizados por outros usurios registrados.",
"MYACCT_FORM_LOGIN"=>"Login",
"MYACCT_FORM_REALNAME"=>"Nome",
"MYACCT_FORM_PASSWD_INFO"=>"Se voc no deseja alterar sua senha, deixe os campos de senha em branco",
"MYACCT_FORM_PASSWD"=>"Senha",
"MYACCT_FORM_PASSWD2"=>"Confirme a senha",
"MYACCT_FORM_EMAIL"=>"E-mail (a conta ser ativada pelo e-mail)",
"MYACCT_FORM_SEX"=>"Sexo",
"MYACCT_FORM_COUNTRY"=>"Pas",
"MYACCT_FORM_CITY"=>"Cidade",
"MYACCT_FORM_STATE"=>"Estado",
"MYACCT_FORM_RCVNEWS"=>"Deseja receber um e-mail com as novidades do site?",
"MYACCT_FORM_RCVREL"=>"Deseja receber um e-mail quando um arquivo  publicado?",
"MYACCT_FORM_URL"=>"Seu site: (inicie com http://)",
"MYACCT_FORM_OBS"=>"Comentrios sobre voc:",
"MYACCT_FORM_SUBMIT"=>"Enviar",
"MYACCT_NEWSPOSTED"=>"Novidades enviadas",
"MYACCT_COMMENTSPOSTED"=>"Comentrios enviados",
"MYACCT_FAQPOSTED"=>"FAQs enviadas",
"MYACCT_DATEACTIVATED"=>"Membro desde",
"MYACCT_LASTVISIT"=>"ltimo login",
"MYACCT_NUMLOGINS"=>"Total de visitas",
"MYACCT_LOGGED"=>"Voc no pode se registrar porque voc j se registrou neste site.",

"MYACCT_USER_BOOK"=>"Meus contatos",
"MYACCT_ADD_USER"=>"Adicionar usurio  minha lista de contatos",
"MYACCT_USER_ADDED"=>"Contato adicionado",
"MYACCT_DEL_USER"=>"Excluir contato da minha lista de contatos",
"MYACCT_USER_DELETED"=>"Contato removido",
"MYACCT_PROFILE"=>"Perfil do usurio ",

"MYACCT_INS_ERROR_01"=>"Voc deve informar a senha",
"MYACCT_INS_ERROR_02"=>"As senhas esto diferentes",
"MYACCT_INS_ERROR_03"=>"Por favor informe seu nome",
"MYACCT_INS_ERROR_04"=>"Utilize somente letras, nmeros e \'_,.,-\' no nome ou login",
"MYACCT_INS_ERROR_05"=>"Informe o pas",
"MYACCT_INS_ERROR_06"=>"Este e-mail j est registrado! Se voc quer excluir ele do site, envie um e-mail para",
"MYACCT_INS_ERROR_07"=>"Este login j existe no site.<br>Por favor escolha outro login",
"MYACCT_INVALID_VALUE"=>"Resposta invlida para a pergunta",
"MYACCT_EMAIL_CHANGED_TITLE"=>"E-mail alterado",
"MYACCT_EMAIL_CHANGED_TEXT"=>"Seu novo e-mail somete ser alterado aps ativ-lo. Em alguns minutos voc ir receber instrues de como ativ-lo no e-mail que voc informou (%s). <b>At l seu antigo e-mail ainda funcionar neste site.</b>",
"MYACCT_EMAIL_CHANGED_MAIL_TITLE"=>"Alterando seu e-mail em %s",
"MYACCT_EMAIL_CHANGED_MAIL_TEXT"=>"Ol %s!\nVoc est alterando seu e-mail no site %s!\nPara ativar seu novo e-mail, v para o endereo: %s\n\nAtenciosamente,\n%s",
"MYACCT_EMAIL_CHANGED_OK"=>"Seu e-mail foi alterado!",
"MYACCT_EMAIL_CHANGED_ERROR"=>"Usurio/sesso invlidos.",

"NEWUSER_TITLE"=>"Novo usurio",
"NEWUSER_MAIL_TITLE"=>"%s - registro",
"NEWUSER_MAIL_TEXT"=>"Ol %s!\nObrigado por se registrar no site %s!\nPara ativar sua conta, v para o endereo %s\n\nAtenciosamente,%s",
"NEWUSER_MSG_TITLE"=>"Voc est quase registrado",
"NEWUSER_MSG_TEXT"=>"<b>Obrigado</b> por se registrar em nosso site!<br><br>Sua conta ainda no est ativa, mas em alguns minutos voc ir receber um e-mail explicando como ativar sua conta.",
"NEWUSER_MSG_TITLE2"=>"Obrigado por se registrar!",
"NEWUSER_MSG_TEXT2"=>"<b>Obrigado</b> por se registrar em nosso site!<br><br>Agora voc pode se logar em nosso site.",
"NEWUSER_FORM_TITLE"=>"Registrar",
"NEWUSER_ACTIVATE_ERROR"=>"Usurio/sesso invlidos ou conta j ativada.",
"NEWUSER_ACTIVATED"=>"Sua conta foi ativada! Agora voc pode enviar mensagens nos fruns e tambm para outros usurios deste site. Para ver a lista de usurios e adicon-los  sua lista de contatos, v para \"MInha conta\" e clique no link \"adicionar contatos\".<br><br>Obrigado por se registrar!",
"NEW_USER_LINK"=>"Registre-se",
//Login
"LOGIN_TITLE"=>"Login",
"LOGIN_NAME"=>"Login:",
"LOGIN_PASSWD"=>"Senha:",
"LOGIN_BUTTON"=>"Login",
"LOGIN_REGISTER"=>"Registre-se,  grtis!",
"LOGIN_LOST_PWD"=>"Perdeu sua senha?",
"LOGIN_WELCOME"=>"Seja bem vindo %s",
"LOGIN_LOGOUT"=>"sair",
"LOGIN_AUTOLOGIN"=>"lembre me",

//Users online
"USERS_ONLINE"=>"Usurios Online",
"USERS_ONLINE_TEXT"=>"Existem:<br>%d usurios registrados<br>e %d convidados %sonline%s agora.",

//List users
"LIST_USERS_TITLE"=>"Lista de usurios",

// Lost your password?
"PASSWD_TITLE"=>"Recuperar senha",
"PASSWD_MAIL_TITLE"=>"Recuperao de senha em ",
"PASSWD_MAIL_TEXT1"=>"Voc pediu para ns enviarmos para voc sua senha em %s\n\nlogin: %s\nsenha: %s",
"PASSWD_MAIL_TEXT2"=>"Mas sua conta ainda no est ativa, para ativar sua conta, por favor, v para o endereo abaixo:\n",
"PASSWD_MAIL_DONE"=>"Um e-mail foi enviado para voc com seu login.",
"PASSWD_MAIL_ERROR"=>"No foi possvel enviar o e-mail.Erro interno.<br>",
"PASSWD_TEXT"=>"Perdeu sua senha? Precisa receber o r-mail de ativao de novo? Ns podemos enviar para voc! Apenas preencha o formulrio abaixo e ns iremos enviar para voc sua senha e login. Use este formulrio para recuperar apenas a SUA senha.",
"PASSWD_FORM_EMAIL"=>"Informe seu e-mail:",
"PASSWD_FORM_SUBMIT"=>"Recuperar senha",

//stats
"STATS_TITLE"=>"Estatsticas",
"STATS_USERS"=>"Usurios registrados",
"STATS_ACTIVE"=>"Ativados",
"STATS_NOTACTIVE"=>"No ativados",
"STATS_TOTAL"=>"Total",
"STATS_TOPTEN"=>"Pases Topten",
"STATS_LAST_WEEK"=>"Novos usurios esta semana",
"STATS_LAST_MONTHS"=>"Novos usurios / 3 meses",

//send e-mail
"SENDMAIL_MSG_HDR"=>"Ol, %s, \n\n",
"SENDMAIL_MSG_FTR"=>"\n\nAt mais,\n\n%s\n\nEste e-mail foi enviado porque voc se registrou no site %s. Se voc no quer mais receber nenhum e-mail deste site, por favor edite sua conta neste site.",
"SENDMAIL_MAIL_SENT"=>"enviado",
"SENDMAIL_USER"=>"Usurio",
"SENDMAIL_EMAIL"=>"E-mail",
"SENDMAIL_COUNTRY"=>"Pas",
"SENDMAIL_SEND"=>"Enviar",
"SENDMAIL_TEXT"=>"Texto",
"SENDMAIL_SUBMIT"=>"Enviar e-mail",
"SENDMAIL_ACCTO"=>"Enviar e-mails para usurios que:",
"SENDMAIL_ACCNEWS"=>"Aceitam novidades",
"SENDMAIL_ACCFREL"=>"Aceitam novos lanamentos",
"SENDMAIL_CONTINUE"=>"Continue enviando",

// Avatars
"AVATAR_TITLE"=>"Escolha seu Avatar",
"AVATAR_NONE"=>"nenhum/remover atual",
"AVATAR_SELECT"=>"Selecione seu avatar:",
"AVATAR_UPLOAD"=>"ou envie um novo avatar: (100x100).(jpg|gif|png)",
);

//

?>

==> phpwebthings-1.0.zip: phpwebthings-1.0/lang/msg_ptbr.php <==
<?php
// Portuguese - Brasil file for phpwebthings - Paulo Assis <paulo@phpdbform.com>
$lang = array(
"CHARSET"=>"iso-8859-1",
//general
"ACTIVATE_TITLE"=>"Conta ativada!",
"ADD_USERS"=>"Adiciona contatos",
"REPLIES_TO"=>"Responder para",
"PREVIOUS_MSG"=>"Mensagem anterior no tpico",
"BACK_FORUM"=>"Voltar para o frum",
"OPTION_NONE"=>"none",
"GO_BACK"=>"Voltar",
"PAGE_PROCESSED"=>"Pgina processada em %.4f segundos",

// general not logged
"NOT_LOGGED_ONLINE"=>"Desculpe, mas voc precisa se logar no site para ver os usurios online. Se voc no tem um login, porque no se registra?  grtis!",
"NOT_LOGGED_MYACCT"=>"Desculpe, mas voc precisa se logar no site para editar seus dados. Se voc no tem um login, porque no se registra?  grtis!",
"NOT_LOGGED"=>"Desculpe, mas voc precisa se logar no site para acessar esta pgina. Se voc no tem um login, porque no se registra?  grtis!",

//home
"HOME_TITLE"=>"Principal",

//error messages
"ERROR_TITLE"=>"*** ERRO ***",
"ERROR_01"=>"Voc no pode postar uma mensagem sem um ttulo e/ou um texto",
"ERROR_02"=>"Voc precisa informar um ttulo<br>",
"ERROR_03"=>"Voc precisa informar um texto<br>",
"ERROR_04"=>"Ocorreu um erro ao executar um comando SQL",
"ERROR_05"=>"Erro abrindo diretrio",
"ERROR_06"=>"banner no encontrado",
"ERROR_07"=>"arquivo no encontrado",
"ERROR_08"=>"E-mail invlido<br>",
"ERROR_09"=>"E-mail no econtrado!<br>",
"ERROR_10"=>"Erro de anlise: ",
"ERROR_11"=>"Ao negada",

// not logged messages
//NOT_LOGGED_ONLINE
//NOT_LOGGED_MYACCT

// MyAccount / NewUser
"MYACCT_TITLE"=>"Minha conta",
"MYACCT_INFO"=>"Informaes sobre meu login",
"MYACCT_TEXT"=>"Todos os dados informados aqui, menos o e-mail, podero ser visualizados por outros usurios registrados.",
"MYACCT_FORM_LOGIN"=>"Login",
"MYACCT_FORM_REALNAME"=>"Nome",
"MYACCT_FORM_PASSWD_INFO"=>"Se voc no deseja alterar sua senha, deixe os campos de senha em branco",
"MYACCT_FORM_PASSWD"=>"Senha",
"MYACCT_FORM_PASSWD2"=>"Confirme a senha",
"MYACCT_FORM_EMAIL"=>"E-mail (a conta ser ativada pelo e-mail)",
"MYACCT_FORM_SEX"=>"Sexo",
"MYACCT_FORM_COUNTRY"=>"Pas",
"MYACCT_FORM_CITY"=>"Cidade",
"MYACCT_FORM_STATE"=>"Estado",
"MYACCT_FORM_RCVNEWS"=>"Deseja receber um e-mail com as novidades do site?",
"MYACCT_FORM_RCVREL"=>"Deseja receber um e-mail quando um arquivo  publicado?",
"MYACCT_FORM_URL"=>"Seu site: (inicie com http://)",
"MYACCT_FORM_OBS"=>"Comentrios sobre voc:",
"MYACCT_FORM_SUBMIT"=>"Enviar",
"MYACCT_NEWSPOSTED"=>"Novidades enviadas",
"MYACCT_COMMENTSPOSTED"=>"Comentrios enviados",
"MYACCT_FAQPOSTED"=>"FAQs enviadas",
"MYACCT_DATEACTIVATED"=>"Membro desde",
"MYACCT_LASTVISIT"=>"ltimo login",
"MYACCT_NUMLOGINS"=>"Total de visitas",
"MYACCT_LOGGED"=>"Voc no pode se registrar porque voc j se registrou neste site.",

"MYACCT_USER_BOOK"=>"Meus contatos",
"MYACCT_ADD_USER"=>"Adicionar usurio  minha lista de contatos",
"MYACCT_USER_ADDED"=>"Contato adicionado",
"MYACCT_DEL_USER"=>"Excluir contato da minha lista de contatos",
"MYACCT_USER_DELETED"=>"Contato removido",
"MYACCT_PROFILE"=>"Perfil do usurio ",

"MYACCT_INS_ERROR_01"=>"Voc deve informar a senha",
"MYACCT_INS_ERROR_02"=>"As senhas esto diferentes",
"MYACCT_INS_ERROR_03"=>"Por favor informe seu nome",
"MYACCT_INS_ERROR_04"=>"Utilize somente letras, nmeros e \'_,.,-\' no nome ou login",
"MYACCT_INS_ERROR_05"=>"Informe o pas",
"MYACCT_INS_ERROR_06"=>"Este e-mail j est registrado! Se voc quer excluir ele do site, envie um e-mail para",
"MYACCT_INS_ERROR_07"=>"Este login j existe no site.<br>Por favor escolha outro login",
"MYACCT_INVALID_VALUE"=>"Resposta invlida para a pergunta",
"MYACCT_EMAIL_CHANGED_TITLE"=>"E-mail alterado",
"MYACCT_EMAIL_CHANGED_TEXT"=>"Seu novo e-mail somete ser alterado aps ativ-lo. Em alguns minutos voc ir receber instrues de como ativ-lo no e-mail que voc informou (%s). <b>At l seu antigo e-mail ainda funcionar neste site.</b>",
"MYACCT_EMAIL_CHANGED_MAIL_TITLE"=>"Alterando seu e-mail em %s",
"MYACCT_EMAIL_CHANGED_MAIL_TEXT"=>"Ol %s!\nVoc est alterando seu e-mail no site %s!\nPara ativar seu novo e-mail, v para o endereo: %s\n\nAtenciosamente,\n%s",
"MYACCT_EMAIL_CHANGED_OK"=>"Seu e-mail foi alterado!",
"MYACCT_EMAIL_CHANGED_ERROR"=>"Usurio/sesso invlidos.",

"NEWUSER_TITLE"=>"Novo usurio",
"NEWUSER_MAIL_TITLE"=>"%s - registro",
"NEWUSER_MAIL_TEXT"=>"Ol %s!\nObrigado por se registrar no site %s!\nPara ativar sua conta, v para o endereo %s\n\nAtenciosamente,%s",
"NEWUSER_MSG_TITLE"=>"Voc est quase registrado",
"NEWUSER_MSG_TEXT"=>"<b>Obrigado</b> por se registrar em nosso site!<br><br>Sua conta ainda no est ativa, mas em alguns minutos voc ir receber um e-mail explicando como ativar sua conta.",
"NEWUSER_MSG_TITLE2"=>"Obrigado por se registrar!",
"NEWUSER_MSG_TEXT2"=>"<b>Obrigado</b> por se registrar em nosso site!<br><br>Agora voc pode se logar em nosso site.",
"NEWUSER_FORM_TITLE"=>"Registrar",
"NEWUSER_ACTIVATE_ERROR"=>"Usurio/sesso invlidos ou conta j ativada.",
"NEWUSER_ACTIVATED"=>"Sua conta foi ativada! Agora voc pode enviar mensagens nos fruns e tambm para outros usurios deste site. Para ver a lista de usurios e adicon-los  sua lista de contatos, v para \"MInha conta\" e clique no link \"adicionar contatos\".<br><br>Obrigado por se registrar!",
"NEW_USER_LINK"=>"Registre-se",
//Login
"LOGIN_TITLE"=>"Login",
"LOGIN_NAME"=>"Login:",
"LOGIN_PASSWD"=>"Senha:",
"LOGIN_BUTTON"=>"Login",
"LOGIN_REGISTER"=>"Registre-se,  grtis!",
"LOGIN_LOST_PWD"=>"Perdeu sua senha?",
"LOGIN_WELCOME"=>"Seja bem-vindo %s",
"LOGIN_LOGOUT"=>"sair",
"LOGIN_AUTOLOGIN"=>"lembre me",

//Users online
"USERS_ONLINE"=>"Usurios Online",
"USERS_ONLINE_TEXT"=>"Existem:<br>%d usurios registrados<br>e %d convidados %sonline%s agora.",

//List users
"LIST_USERS_TITLE"=>"Lista de usurios",

// Lost your password?
"PASSWD_TITLE"=>"Recuperar senha",
"PASSWD_MAIL_TITLE"=>"Recuperao de senha em ",
"PASSWD_MAIL_TEXT1"=>"Voc pediu para ns enviarmos para voc sua senha em %s\n\nlogin: %s\nsenha: %s",
"PASSWD_MAIL_TEXT2"=>"Mas sua conta ainda no est ativa, para ativar sua conta, por favor, v para o endereo abaixo:\n",
"PASSWD_MAIL_DONE"=>"Um e-mail foi enviado para voc com seu login.",
"PASSWD_MAIL_ERROR"=>"No foi possvel enviar o e-mail.Erro interno.<br>",
"PASSWD_TEXT"=>"Perdeu sua senha? Precisa receber o r-mail de ativao de novo? Ns podemos enviar para voc! Apenas preencha o formulrio abaixo e ns iremos enviar para voc sua senha e login. Use este formulrio para recuperar apenas a SUA senha.",
"PASSWD_FORM_EMAIL"=>"Informe seu e-mail:",
"PASSWD_FORM_SUBMIT"=>"Recuperar senha",

//stats
"STATS_TITLE"=>"Estatsticas",
"STATS_USERS"=>"Usurios registrados",
"STATS_ACTIVE"=>"Ativados",
"STATS_NOTACTIVE"=>"No ativados",
"STATS_TOTAL"=>"Total",
"STATS_TOPTEN"=>"Pases Topten",
"STATS_LAST_WEEK"=>"Novos usurios esta semana",
"STATS_LAST_MONTHS"=>"Novos usurios / 3 meses",

//send e-mail
"SENDMAIL_MSG_HDR"=>"Ol, %s, \n\n",
"SENDMAIL_MSG_FTR"=>"\n\nAt mais,\n\n%s\n\nEste e-mail foi enviado porque voc se registrou no site %s. Se voc no quer mais receber nenhum e-mail deste site, por favor edite sua conta neste site.",
"SENDMAIL_MAIL_SENT"=>"enviado",
"SENDMAIL_USER"=>"Usurio",
"SENDMAIL_EMAIL"=>"E-mail",
"SENDMAIL_COUNTRY"=>"Pas",
"SENDMAIL_SEND"=>"Enviar",
"SENDMAIL_TEXT"=>"Texto",
"SENDMAIL_SUBMIT"=>"Enviar e-mail",
"SENDMAIL_ACCTO"=>"Enviar e-mails para usurios que:",
"SENDMAIL_ACCNEWS"=>"Aceitam novidades",
"SENDMAIL_ACCFREL"=>"Aceitam novos lanamentos",
"SENDMAIL_CONTINUE"=>"Continue enviando",

// Avatars
"AVATAR_TITLE"=>"Escolha seu Avatar",
"AVATAR_NONE"=>"nenhum/remover atual",
"AVATAR_SELECT"=>"Selecione seu avatar:",
"AVATAR_UPLOAD"=>"ou envie um novo avatar: (100x100).(jpg|gif|png)",

// Admmenu
"ADMMNU_INFO"=>"Informaes",
"ADMMNU_WEBADMIN"=>"WebAdmin",
"ADMMNU_SENDEMAIL"=>"Evniar e-mail",
"ADMMNU_USERS"=>"Usurios",
"ADMMNU_USERACCESS"=>"Permisses de acesso",
"ADMMNU_MENU"=>"Menu",

"SIDEBOX_EDIT_TITLE"=>"Side Boxes"
);

//

?>
